@@ -2,9 +2,9 @@
 from __future__ import annotations
 
 import asyncio
-from json import JSONDecodeError
 import logging
 from datetime import datetime, timedelta
+from json import JSONDecodeError
 from typing import Any, Callable
 
 from aiohttp import ClientSession, ClientTimeout
@@ -146,7 +146,7 @@ class DopplerClient:
                 raise CantConnectException(resp_data)
             raise UnknownException(resp_data)
 
-    async def _get_token(self) -> None:
+    async def get_token(self) -> None:
         """Get token."""
         auth_payload = {
             "authenticationDetails": {
@@ -197,7 +197,7 @@ class DopplerClient:
             await self._token_event.wait()
             if not self._access_token:
                 self._token_event.clear()
-                await self._get_token()
+                await self.get_token()
                 self._token_event.set()
             elif datetime.utcnow() > self._access_token_expires:
                 self._token_event.clear()
