@@ -48,7 +48,7 @@ from ..const import (
 from ..exceptions import ExpiredNonce, InvalidAlarmSound
 from .alarm import Alarm
 from .color import Color
-from .light_bar import LightbarDisplayEffect
+from .light_bar import LightBarDisplayEffect
 from .main_display_text import MainDisplayText
 from .mini_display_number import MiniDisplayNumber
 from .sound import SoundPreset
@@ -686,13 +686,12 @@ class Doppler:
         return MiniDisplayNumber.from_dict(params)
 
     async def set_light_bar_effect(
-        self, lbde: LightbarDisplayEffect
-    ) -> LightbarDisplayEffect:
+        self, lbde: LightBarDisplayEffect
+    ) -> LightBarDisplayEffect:
         """Set light bar display effect."""
         data = lbde.to_dict()
-
         params = await self._call_api("hardware/display-dots", "PUT", data)
-        return LightbarDisplayEffect.from_dict(params)
+        return LightBarDisplayEffect.from_dict(params)
 
     async def get_all_data(self) -> dict[str, Any]:
         """Get all data from the device."""
