@@ -4,7 +4,7 @@ from __future__ import annotations
 from enum import Enum
 
 
-class SoundPreset(str, Enum):
+class SoundPreset(Enum):
     """Sound Preset Enum."""
 
     BALANCED = "PRESET1"
